<?php
/**
 * General functions used by Link Mananager 2 plugin.
 *
 * (c)2012 mrdragonraaar.com
 */
if (!defined('IN_GS')) { die('you cannot load this page directly.'); }

// plugin template path
if (!defined('LM2_TEMPLATE_PATH')) {
define('LM2_TEMPLATE_PATH', LM2_PLUGIN_PATH . 'template/');
}

require_once('lib/LinkManager/LinkManager.php');

/**
 * Main back-end plugin function.
 * Determine what action to take.
 */
function lm2_main()
{
	global $lm2;

	if ($lm2::is_link_page())
	{
		if ($lm2::is_post_link())
		{
			$lm2->add_post_link();
			if ($lm2->save_links())
				lm2_admin_message(true);
			else
				lm2_admin_message(false);
			lm2_admin_link_panel();
		}
		elseif ($lm2::is_post_link_order())
		{
			$lm2->order_post_links();
			if ($lm2->save_links())
				lm2_admin_message(true);
			else
				lm2_admin_message(false);
			lm2_admin_link_panel();
		}
		elseif ($lm2::is_edit_page())
		{
			lm2_edit_link_panel();
		}
		elseif ($lm2::is_delete_page())
		{
			$lm2->delete_link();
			if ($lm2->save_links())
				lm2_admin_message(true);
			else
				lm2_admin_message(false);
			lm2_admin_link_panel();
		}
		elseif ($lm2::is_undo_page())
		{
			if ($lm2->undo_links())
				lm2_admin_message(true);
			else
				lm2_admin_message(false);
			lm2_admin_link_panel();
		}
		else
		{
			lm2_admin_link_panel();
		}
	}

	if ($lm2::is_category_page())
	{
		if ($lm2::is_post_category())
		{
			$lm2->add_post_category();
			if ($lm2->save_categories())
				lm2_admin_message(true);
			else
				lm2_admin_message(false);
			lm2_admin_category_panel();
		}
		elseif ($lm2::is_edit_page())
		{
			lm2_edit_category_panel();
		}
		elseif ($lm2::is_delete_page())
		{
			$lm2->delete_category();
			if ($lm2->save_categories())
				lm2_admin_message(true);
			else
				lm2_admin_message(false);
			lm2_admin_category_panel();
		}
		elseif ($lm2::is_undo_page())
		{
			if ($lm2->undo_categories())
				lm2_admin_message(true);
			else
				lm2_admin_message(false);
			lm2_admin_category_panel();
		}
		else
		{
			lm2_admin_category_panel();
		}
	}
}

/**
 * Display admin panel for links.
 */
function lm2_admin_link_panel()
{
	global $lm2;

	include(LM2_TEMPLATE_PATH . 'admin_link_panel.php');
}

/**
 * Display admin panel for edit link.
 */
function lm2_edit_link_panel()
{
	global $lm2;

	include(LM2_TEMPLATE_PATH . 'edit_link_panel.php');
}

/**
 * Display admin panel for categories.
 */
function lm2_admin_category_panel()
{
	global $lm2;

	include(LM2_TEMPLATE_PATH . 'admin_category_panel.php');
}

/**
 * Display admin panel for edit category.
 */
function lm2_edit_category_panel()
{
	global $lm2;

	include(LM2_TEMPLATE_PATH . 'edit_category_panel.php');
}

/**
 * Display message on admin panel.
 * @param $success denotes whether to display success message.
 */
function lm2_admin_message($success)
{
	global $lm2;

	include(LM2_TEMPLATE_PATH . 'admin_message.php');
}

/**
 * Front-end plugin function.
 * Display list of links.
 * @param $category_id category id
 */
function lm2_list_links($category_id = '')
{
	global $lm2;

	include(LM2_TEMPLATE_PATH . 'links_html.php');
}

/**
 * Front-end plugin function.
 * Display category name.
 * @param $category_id category id
 */
function lm2_category($category_id = '')
{
	echo lm2_get_category($category_id);
}

/**
 * Get category name.
 * @param $category_id category id
 */
function lm2_get_category($category_id = '')
{
	global $lm2;

	return $lm2->category_name($category_id);
}

/**
 * Get list of links.
 * @param $category_id category id
 */
function lm2_get_list_links($category_id = '')
{
	ob_start();
	lm2_list_links($category_id);
	return ob_get_clean();
}

/**
 * Front-end plugin function for filter.
 * Insert list of links into content.
 * @param $content page content
 */
function lm2_filter($content)
{
	if (preg_match('/\(%\s*links\s*%\)/', $content))
	{
		$html = lm2_get_list_links();
		$content = preg_replace('/\(%\s*links\s*%\)/', $html, $content);
	}

	if (preg_match('/\(%\s*links:(\d*)\s*%\)/', $content, $matches))
	{
		$content = preg_replace('/\(%\s*links:(\d*)\s*%\)/e', 'lm2_get_list_links(intval($1))', $content);
	}

	if (preg_match('/\(%\s*link_category:(\d*)\s*%\)/', $content, $matches))
	{
		$content = preg_replace('/\(%\s*link_category:(\d*)\s*%\)/e', 'lm2_get_category(intval($1))', $content);
	}

	return $content;
}

?>
